JoltLintPlugin class

JoltLint plugin implementation.

Provides lint rules, quick fixes, and code assists for the Jolt reactive state management ecosystem.

Inheritance
  • Object
  • Plugin
  • JoltLintPlugin

Constructors

JoltLintPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of this plugin.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(PluginRegistry registry) → void
Registers all lint rules, fixes, and assists with the analyzer.
override
shutDown() FutureOr<void>
inherited
start() FutureOr<void>
Initializes any necessary start-up state that is required for this plugin to run.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited