plugin top-level property

JoltLintPlugin plugin
final

JoltLint plugin instance.

This is the main entry point for the Jolt lint tool. The analyzer will automatically discover and use this plugin when the package is added to analysis_options.yaml.

Implementation

final plugin = JoltLintPlugin();